@@ -1,21 +1,30 @@
 """test_helpers_date_ops"""
+
 from datetime import datetime
 from unittest import TestCase
 from unittest.mock import Mock
 import pytest
-from elasticsearch8 import NotFoundError
+from elasticsearch9 import NotFoundError
 from elastic_transport import ApiResponseMeta
 from curator.exceptions import ConfigurationError
 from curator.helpers.date_ops import (
-    absolute_date_range, date_range, datetime_to_epoch, fix_epoch, get_date_regex, get_datemath,
-    get_point_of_reference, isdatemath
+    absolute_date_range,
+    date_range,
+    datetime_to_epoch,
+    fix_epoch,
+    get_date_regex,
+    get_datemath,
+    get_point_of_reference,
+    isdatemath,
 )
 
+
 class TestGetDateRegex(TestCase):
     """TestGetDateRegex
 
     Test helpers.date_ops.get_date_regex functionality.
     """
+
     def test_non_escaped(self):
         """test_non_escaped
 
@@ -23,11 +32,13 @@ class TestGetDateRegex(TestCase):
         """
         assert '\\d{4}\\-\\d{2}\\-\\d{2}t\\d{2}' == get_date_regex('%Y-%m-%dt%H')
 
+
 class TestFixEpoch(TestCase):
     """TestFixEpoch
 
     Test helpers.date_ops.fix_epoch functionality.
     """
+
     def test_fix_epoch(self):
         """test_fix_epoch
 
@@ -42,8 +53,9 @@ class TestFixEpoch(TestCase):
             (145928763600000000, 1459287636),
             (145928763600000001, 1459287636),
             (1459287636123456789, 1459287636),
-                ]:
+        ]:
             assert epoch == fix_epoch(long_epoch)
+
     def test_fix_epoch_raise(self):
         """test_fix_epoch_raise
 
@@ -52,11 +64,13 @@ class TestFixEpoch(TestCase):
         with pytest.raises(ValueError):
             fix_epoch(None)
 
+
 class TestGetPointOfReference(TestCase):
     """TestGetPointOfReference
 
     Test helpers.date_ops.get_point_of_reference functionality.
     """
+
     def test_get_point_of_reference(self):
         """test_get_point_of_reference
 
@@ -64,16 +78,17 @@ class TestGetPointOfReference(TestCase):
         """
         epoch = 1459288037
         for unit, result in [
-            ('seconds', epoch-1),
-            ('minutes', epoch-60),
-            ('hours', epoch-3600),
-            ('days', epoch-86400),
-            ('weeks', epoch-(86400*7)),
-            ('months', epoch-(86400*30)),
-            ('years', epoch-(86400*365)),
-                ]:
+            ('seconds', epoch - 1),
+            ('minutes', epoch - 60),
+            ('hours', epoch - 3600),
+            ('days', epoch - 86400),
+            ('weeks', epoch - (86400 * 7)),
+            ('months', epoch - (86400 * 30)),
+            ('years', epoch - (86400 * 365)),
+        ]:
             # self.assertEqual(result, get_point_of_reference(unit, 1, epoch))
             assert result == get_point_of_reference(unit, 1, epoch)
+
     def test_get_por_raise(self):
         """test_get_por_raise
 
@@ -83,12 +98,15 @@ class TestGetPointOfReference(TestCase):
         with pytest.raises(ValueError):
             get_point_of_reference('invalid', 1)
 
+
 class TestDateRange(TestCase):
     """TestDateRange
 
     Test helpers.date_ops.date_range functionality.
     """
-    EPOCH = datetime_to_epoch(datetime(2017,  4,  3, 22, 50, 17))
+
+    EPOCH = datetime_to_epoch(datetime(2017, 4, 3, 22, 50, 17))
+
     def test_bad_unit(self):
         """test_bad_unit
 
@@ -96,13 +114,17 @@ class TestDateRange(TestCase):
         """
         with pytest.raises(ConfigurationError, match=r'"unit" must be one of'):
             date_range('invalid', 1, 1)
+
     def test_bad_range(self):
         """test_bad_range
 
         Should raise a ``ConfigurationError`` exception when an improper range value is passed
         """
-        with pytest.raises(ConfigurationError, match=r'must be greater than or equal to'):
+        with pytest.raises(
+            ConfigurationError, match=r'must be greater than or equal to'
+        ):
             date_range('hours', 1, -1)
+
     def test_hours_single(self):
         """test_hours_single
 
@@ -111,9 +133,10 @@ class TestDateRange(TestCase):
         unit = 'hours'
         range_from = -1
         range_to = -1
-        start = datetime_to_epoch(datetime(2017,  4,  3, 21,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  4,  3, 21, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 4, 3, 21, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 4, 3, 21, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_hours_past_range(self):
         """test_hours_past_range
 
@@ -122,9 +145,10 @@ class TestDateRange(TestCase):
         unit = 'hours'
         range_from = -3
         range_to = -1
-        start = datetime_to_epoch(datetime(2017,  4,  3, 19,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  4,  3, 21, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 4, 3, 19, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 4, 3, 21, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_hours_future_range(self):
         """test_hours_future_range
 
@@ -133,9 +157,10 @@ class TestDateRange(TestCase):
         unit = 'hours'
         range_from = 0
         range_to = 2
-        start = datetime_to_epoch(datetime(2017,  4,  3, 22,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  4,  4, 00, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 4, 3, 22, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 4, 4, 00, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_hours_span_range(self):
         """test_hours_span_range
 
@@ -144,9 +169,10 @@ class TestDateRange(TestCase):
         unit = 'hours'
         range_from = -1
         range_to = 2
-        start = datetime_to_epoch(datetime(2017,  4,  3, 21,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  4,  4, 00, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 4, 3, 21, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 4, 4, 00, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_days_single(self):
         """test_days_single
 
@@ -155,9 +181,10 @@ class TestDateRange(TestCase):
         unit = 'days'
         range_from = -1
         range_to = -1
-        start = datetime_to_epoch(datetime(2017,  4,  2,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  4,  2, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 4, 2, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 4, 2, 23, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_days_past_range(self):
         """test_days_range
 
@@ -166,9 +193,10 @@ class TestDateRange(TestCase):
         unit = 'days'
         range_from = -3
         range_to = -1
-        start = datetime_to_epoch(datetime(2017,  3, 31,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  4,  2, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 3, 31, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 4, 2, 23, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_days_future_range(self):
         """test_days_future_range
 
@@ -177,9 +205,10 @@ class TestDateRange(TestCase):
         unit = 'days'
         range_from = 0
         range_to = 2
-        start = datetime_to_epoch(datetime(2017,  4,  3,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  4,  5, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 4, 3, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 4, 5, 23, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_days_span_range(self):
         """test_days_span_range
 
@@ -188,9 +217,10 @@ class TestDateRange(TestCase):
         unit = 'days'
         range_from = -1
         range_to = 2
-        start = datetime_to_epoch(datetime(2017,  4,  2,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  4,  5, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 4, 2, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 4, 5, 23, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_weeks_single(self):
         """test_weeks_single
 
@@ -199,9 +229,10 @@ class TestDateRange(TestCase):
         unit = 'weeks'
         range_from = -1
         range_to = -1
-        start = datetime_to_epoch(datetime(2017,  3, 26,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  4,  1, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 3, 26, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 4, 1, 23, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_weeks_past_range(self):
         """test_weeks_past_range
 
@@ -210,9 +241,10 @@ class TestDateRange(TestCase):
         unit = 'weeks'
         range_from = -3
         range_to = -1
-        start = datetime_to_epoch(datetime(2017,  3, 12,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  4,  1, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 3, 12, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 4, 1, 23, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_weeks_future_range(self):
         """test_weeks_future_range
 
@@ -221,9 +253,10 @@ class TestDateRange(TestCase):
         unit = 'weeks'
         range_from = 0
         range_to = 2
-        start = datetime_to_epoch(datetime(2017,  4,  2, 00,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  4, 22, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 4, 2, 00, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 4, 22, 23, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_weeks_span_range(self):
         """test_weeks_span_range
 
@@ -232,9 +265,10 @@ class TestDateRange(TestCase):
         unit = 'weeks'
         range_from = -1
         range_to = 2
-        start = datetime_to_epoch(datetime(2017,  3, 26,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  4, 22, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 3, 26, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 4, 22, 23, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_weeks_single_iso(self):
         """test_weeks_single_iso
 
@@ -244,10 +278,13 @@ class TestDateRange(TestCase):
         unit = 'weeks'
         range_from = -1
         range_to = -1
-        start = datetime_to_epoch(datetime(2017,  3, 27,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  4,  2, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 3, 27, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 4, 2, 23, 59, 59))
         # pylint: disable=line-too-long
-        assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH, week_starts_on='monday')
+        assert (start, end) == date_range(
+            unit, range_from, range_to, epoch=self.EPOCH, week_starts_on='monday'
+        )
+
     def test_weeks_past_range_iso(self):
         """test_weeks_past_range_iso
 
@@ -257,10 +294,13 @@ class TestDateRange(TestCase):
         unit = 'weeks'
         range_from = -3
         range_to = -1
-        start = datetime_to_epoch(datetime(2017,  3, 13,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  4,  2, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 3, 13, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 4, 2, 23, 59, 59))
         # pylint: disable=line-too-long
-        assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH, week_starts_on='monday')
+        assert (start, end) == date_range(
+            unit, range_from, range_to, epoch=self.EPOCH, week_starts_on='monday'
+        )
+
     def test_weeks_future_range_iso(self):
         """test_weeks_future_range_iso
 
@@ -270,10 +310,13 @@ class TestDateRange(TestCase):
         unit = 'weeks'
         range_from = 0
         range_to = 2
-        start = datetime_to_epoch(datetime(2017,  4,  3,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  4, 23, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 4, 3, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 4, 23, 23, 59, 59))
         # pylint: disable=line-too-long
-        assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH, week_starts_on='monday')
+        assert (start, end) == date_range(
+            unit, range_from, range_to, epoch=self.EPOCH, week_starts_on='monday'
+        )
+
     def test_weeks_span_range_iso(self):
         """test_weeks_span_range_iso
 
@@ -283,10 +326,13 @@ class TestDateRange(TestCase):
         unit = 'weeks'
         range_from = -1
         range_to = 2
-        start = datetime_to_epoch(datetime(2017,  3, 27,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  4, 23, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 3, 27, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 4, 23, 23, 59, 59))
         # pylint: disable=line-too-long
-        assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH, week_starts_on='monday')
+        assert (start, end) == date_range(
+            unit, range_from, range_to, epoch=self.EPOCH, week_starts_on='monday'
+        )
+
     def test_months_single(self):
         """test_months_single
 
@@ -295,9 +341,10 @@ class TestDateRange(TestCase):
         unit = 'months'
         range_from = -1
         range_to = -1
-        start = datetime_to_epoch(datetime(2017,  3,  1,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  3, 31, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 3, 1, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 3, 31, 23, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_months_past_range(self):
         """test_months_past_range
 
@@ -306,9 +353,10 @@ class TestDateRange(TestCase):
         unit = 'months'
         range_from = -4
         range_to = -1
-        start = datetime_to_epoch(datetime(2016, 12,  1,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  3, 31, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2016, 12, 1, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 3, 31, 23, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_months_future_range(self):
         """test_months_future_range
 
@@ -317,9 +365,10 @@ class TestDateRange(TestCase):
         unit = 'months'
         range_from = 7
         range_to = 10
-        start = datetime_to_epoch(datetime(2017, 11,  1,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2018,  2, 28, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 11, 1, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2018, 2, 28, 23, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_months_super_future_range(self):
         """test_months_super_future_range
 
@@ -328,9 +377,10 @@ class TestDateRange(TestCase):
         unit = 'months'
         range_from = 9
         range_to = 10
-        start = datetime_to_epoch(datetime(2018,  1,  1,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2018,  2, 28, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2018, 1, 1, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2018, 2, 28, 23, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_months_span_range(self):
         """test_months_span_range
 
@@ -340,9 +390,10 @@ class TestDateRange(TestCase):
         range_from = -1
         range_to = 2
 
-        start = datetime_to_epoch(datetime(2017,  3,  1,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  6, 30, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 3, 1, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 6, 30, 23, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_years_single(self):
         """test_years_single
 
@@ -351,9 +402,10 @@ class TestDateRange(TestCase):
         unit = 'years'
         range_from = -1
         range_to = -1
-        start = datetime_to_epoch(datetime(2016,  1,  1,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2016, 12, 31, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2016, 1, 1, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2016, 12, 31, 23, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_years_past_range(self):
         """test_years_past_range
 
@@ -362,9 +414,10 @@ class TestDateRange(TestCase):
         unit = 'years'
         range_from = -3
         range_to = -1
-        start = datetime_to_epoch(datetime(2014,  1,  1,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2016, 12, 31, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2014, 1, 1, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2016, 12, 31, 23, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_years_future_range(self):
         """test_years_future_range
 
@@ -373,9 +426,10 @@ class TestDateRange(TestCase):
         unit = 'years'
         range_from = 0
         range_to = 2
-        start = datetime_to_epoch(datetime(2017,  1,  1,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2019, 12, 31, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2017, 1, 1, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2019, 12, 31, 23, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
+
     def test_years_span_range(self):
         """test_years_span_range
 
@@ -384,15 +438,17 @@ class TestDateRange(TestCase):
         unit = 'years'
         range_from = -1
         range_to = 2
-        start = datetime_to_epoch(datetime(2016,  1,  1,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2019, 12, 31, 23, 59, 59))
+        start = datetime_to_epoch(datetime(2016, 1, 1, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2019, 12, 31, 23, 59, 59))
         assert (start, end) == date_range(unit, range_from, range_to, epoch=self.EPOCH)
 
+
 class TestAbsoluteDateRange(TestCase):
     """TestAbsoluteDateRange
 
     Test helpers.date_ops.absolute_date_range functionality.
     """
+
     def test_bad_unit(self):
         """test_bad_unit
 
@@ -404,7 +460,10 @@ class TestAbsoluteDateRange(TestCase):
         date_to = '2017.01'
         date_to_format = '%Y.%m'
         with pytest.raises(ConfigurationError, match=r'"unit" must be one of'):
-            absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format)
+            absolute_date_range(
+                unit, date_from, date_to, date_from_format, date_to_format
+            )
+
     def test_bad_formats(self):
         """test_bad_formats
 
@@ -412,10 +471,17 @@ class TestAbsoluteDateRange(TestCase):
         ``date_to_format`` is passed.
         """
         unit = 'days'
-        with pytest.raises(ConfigurationError, match=r'Must provide "date_from_format" and "date_to_format"'):
+        with pytest.raises(
+            ConfigurationError,
+            match=r'Must provide "date_from_format" and "date_to_format"',
+        ):
             absolute_date_range(unit, 'meh', 'meh', None, 'meh')
-        with pytest.raises(ConfigurationError, match=r'Must provide "date_from_format" and "date_to_format"'):
+        with pytest.raises(
+            ConfigurationError,
+            match=r'Must provide "date_from_format" and "date_to_format"',
+        ):
             absolute_date_range(unit, 'meh', 'meh', 'meh', None)
+
     def test_bad_dates(self):
         """test_bad_dates
 
@@ -426,9 +492,14 @@ class TestAbsoluteDateRange(TestCase):
         date_from_format = '%Y.%m'
         date_to_format = '%Y.%m'
         with pytest.raises(ConfigurationError, match=r'Unable to parse "date_from"'):
-            absolute_date_range(unit, 'meh', '2017.01', date_from_format, date_to_format)
+            absolute_date_range(
+                unit, 'meh', '2017.01', date_from_format, date_to_format
+            )
         with pytest.raises(ConfigurationError, match=r'Unable to parse "date_to"'):
-            absolute_date_range(unit, '2017.01', 'meh', date_from_format, date_to_format)
+            absolute_date_range(
+                unit, '2017.01', 'meh', date_from_format, date_to_format
+            )
+
     def test_single_month(self):
         """test_single_month
 
@@ -439,10 +510,13 @@ class TestAbsoluteDateRange(TestCase):
         date_from_format = '%Y.%m'
         date_to = '2017.01'
         date_to_format = '%Y.%m'
-        start = datetime_to_epoch(datetime(2017,  1,  1,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  1, 31, 23, 59, 59))
-        result = absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format)
+        start = datetime_to_epoch(datetime(2017, 1, 1, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 1, 31, 23, 59, 59))
+        result = absolute_date_range(
+            unit, date_from, date_to, date_from_format, date_to_format
+        )
         assert (start, end) == result
+
     def test_multiple_month(self):
         """test_multiple_month
 
@@ -453,10 +527,13 @@ class TestAbsoluteDateRange(TestCase):
         date_from_format = '%Y.%m'
         date_to = '2016.12'
         date_to_format = '%Y.%m'
-        start = datetime_to_epoch(datetime(2016, 11,  1,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2016, 12, 31, 23, 59, 59))
-        result = absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format)
+        start = datetime_to_epoch(datetime(2016, 11, 1, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2016, 12, 31, 23, 59, 59))
+        result = absolute_date_range(
+            unit, date_from, date_to, date_from_format, date_to_format
+        )
         assert (start, end) == result
+
     def test_single_year(self):
         """test_single_year
 
@@ -467,10 +544,13 @@ class TestAbsoluteDateRange(TestCase):
         date_from_format = '%Y'
         date_to = '2017'
         date_to_format = '%Y'
-        start = datetime_to_epoch(datetime(2017,  1,  1,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017, 12, 31, 23, 59, 59))
-        result = absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format)
+        start = datetime_to_epoch(datetime(2017, 1, 1, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 12, 31, 23, 59, 59))
+        result = absolute_date_range(
+            unit, date_from, date_to, date_from_format, date_to_format
+        )
         assert (start, end) == result
+
     def test_multiple_year(self):
         """test_multiple_year
 
@@ -481,10 +561,13 @@ class TestAbsoluteDateRange(TestCase):
         date_from_format = '%Y'
         date_to = '2017'
         date_to_format = '%Y'
-        start = datetime_to_epoch(datetime(2016,  1,  1,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017, 12, 31, 23, 59, 59))
-        result = absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format)
+        start = datetime_to_epoch(datetime(2016, 1, 1, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 12, 31, 23, 59, 59))
+        result = absolute_date_range(
+            unit, date_from, date_to, date_from_format, date_to_format
+        )
         assert (start, end) == result
+
     def test_single_week_uw(self):
         """test_single_week_UW
 
@@ -495,10 +578,13 @@ class TestAbsoluteDateRange(TestCase):
         date_from_format = '%Y-%U'
         date_to = '2017-01'
         date_to_format = '%Y-%U'
-        start = datetime_to_epoch(datetime(2017,  1,  2,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  1,  8, 23, 59, 59))
-        result = absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format)
+        start = datetime_to_epoch(datetime(2017, 1, 2, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 1, 8, 23, 59, 59))
+        result = absolute_date_range(
+            unit, date_from, date_to, date_from_format, date_to_format
+        )
         assert (start, end) == result
+
     def test_multiple_weeks_uw(self):
         """test_multiple_weeks_UW
 
@@ -509,10 +595,13 @@ class TestAbsoluteDateRange(TestCase):
         date_from_format = '%Y-%U'
         date_to = '2017-04'
         date_to_format = '%Y-%U'
-        start = datetime_to_epoch(datetime(2017,  1,   2,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  1,  29, 23, 59, 59))
-        result = absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format)
+        start = datetime_to_epoch(datetime(2017, 1, 2, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 1, 29, 23, 59, 59))
+        result = absolute_date_range(
+            unit, date_from, date_to, date_from_format, date_to_format
+        )
         assert (start, end) == result
+
     def test_single_week_iso(self):
         """test_single_week_ISO
 
@@ -523,10 +612,13 @@ class TestAbsoluteDateRange(TestCase):
         date_from_format = '%G-%V'
         date_to = '2014-01'
         date_to_format = '%G-%V'
-        start = datetime_to_epoch(datetime(2013, 12, 30,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2014,  1,  5, 23, 59, 59))
-        result = absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format)
+        start = datetime_to_epoch(datetime(2013, 12, 30, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2014, 1, 5, 23, 59, 59))
+        result = absolute_date_range(
+            unit, date_from, date_to, date_from_format, date_to_format
+        )
         assert (start, end) == result
+
     def test_multiple_weeks_iso(self):
         """test_multiple_weeks_ISO
 
@@ -537,10 +629,13 @@ class TestAbsoluteDateRange(TestCase):
         date_from_format = '%G-%V'
         date_to = '2014-04'
         date_to_format = '%G-%V'
-        start = datetime_to_epoch(datetime(2013, 12, 30,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2014,  1, 26, 23, 59, 59))
-        result = absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format)
+        start = datetime_to_epoch(datetime(2013, 12, 30, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2014, 1, 26, 23, 59, 59))
+        result = absolute_date_range(
+            unit, date_from, date_to, date_from_format, date_to_format
+        )
         assert (start, end) == result
+
     def test_single_day(self):
         """test_single_day
 
@@ -551,10 +646,13 @@ class TestAbsoluteDateRange(TestCase):
         date_from_format = '%Y.%m.%d'
         date_to = '2017.01.01'
         date_to_format = '%Y.%m.%d'
-        start = datetime_to_epoch(datetime(2017,  1,  1,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  1,  1, 23, 59, 59))
-        result = absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format)
+        start = datetime_to_epoch(datetime(2017, 1, 1, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 1, 1, 23, 59, 59))
+        result = absolute_date_range(
+            unit, date_from, date_to, date_from_format, date_to_format
+        )
         assert (start, end) == result
+
     def test_multiple_days(self):
         """test_multiple_days
 
@@ -565,10 +663,13 @@ class TestAbsoluteDateRange(TestCase):
         date_from_format = '%Y.%m.%d'
         date_to = '2017.01.01'
         date_to_format = '%Y.%m.%d'
-        start = datetime_to_epoch(datetime(2016, 12, 31,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  1,  1, 23, 59, 59))
-        result = absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format)
+        start = datetime_to_epoch(datetime(2016, 12, 31, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 1, 1, 23, 59, 59))
+        result = absolute_date_range(
+            unit, date_from, date_to, date_from_format, date_to_format
+        )
         assert (start, end) == result
+
     def test_iso8601(self):
         """test_ISO8601
 
@@ -579,16 +680,20 @@ class TestAbsoluteDateRange(TestCase):
         date_from_format = '%Y-%m-%dT%H:%M:%S'
         date_to = '2017-01-01T12:34:56'
         date_to_format = '%Y-%m-%dT%H:%M:%S'
-        start = datetime_to_epoch(datetime(2017,  1,  1,  0,  0,  0))
-        end   = datetime_to_epoch(datetime(2017,  1,  1, 12, 34, 56))
-        result = absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format)
+        start = datetime_to_epoch(datetime(2017, 1, 1, 0, 0, 0))
+        end = datetime_to_epoch(datetime(2017, 1, 1, 12, 34, 56))
+        result = absolute_date_range(
+            unit, date_from, date_to, date_from_format, date_to_format
+        )
         assert (start, end) == result
 
+
 class TestIsDateMath(TestCase):
     """TestIsDateMath
 
     Test helpers.date_ops.isdatemath functionality.
     """
+
     def test_positive(self):
         """test_positive
 
@@ -596,6 +701,7 @@ class TestIsDateMath(TestCase):
         """
         data = '<encapsulated>'
         assert isdatemath(data)
+
     def test_negative(self):
         """test_negative
 
@@ -603,20 +709,25 @@ class TestIsDateMath(TestCase):
         """
         data = 'not_encapsulated'
         assert not isdatemath(data)
+
     def test_raises(self):
         """test_raises
 
         Should raise ConfigurationError exception when malformed data is passed
         """
         data = '<badly_encapsulated'
-        with pytest.raises(ConfigurationError, match=r'Incomplete datemath encapsulation'):
+        with pytest.raises(
+            ConfigurationError, match=r'Incomplete datemath encapsulation'
+        ):
             isdatemath(data)
 
+
 class TestGetDateMath(TestCase):
     """TestGetDateMath
 
     Test helpers.date_ops.get_datemath functionality.
     """
+
     def test_success(self):
         """test_success
 
@@ -628,12 +739,13 @@ class TestGetDateMath(TestCase):
         expected = 'curator_get_datemath_function_' + psuedo_random + '-hasthemath'
         # 5 positional args for meta: status, http_version, headers, duration, node
         meta = ApiResponseMeta(404, '1.1', {}, 0.01, None)
-        body = {'error':{'index':expected}}
+        body = {'error': {'index': expected}}
         msg = 'index_not_found_exception'
         # 3 positional args for NotFoundError: message, meta, body
         effect = NotFoundError(msg, meta, body)
         client.indices.get.side_effect = effect
         self.assertEqual('hasthemath', get_datemath(client, datemath, psuedo_random))
+
     def test_failure(self):
         """test_failure
 
@@ -643,7 +755,7 @@ class TestGetDateMath(TestCase):
         datemath = '{hasthemath}'
         # 5 positional args for meta: status, http_version, headers, duration, node
         meta = ApiResponseMeta(404, '1.1', {}, 0.01, None)
-        body = {'error':{'index':'this_will_not_be_found'}}
+        body = {'error': {'index': 'this_will_not_be_found'}}
         msg = 'index_not_found_exception'
         # 3 positional args for NotFoundError: message, meta, body
         effect = NotFoundError(msg, meta, body)
